@@ -10,6 +10,7 @@ from vessl.cli._util import (
     print_table,
     print_volume_files,
     prompt_choices,
+    truncate_datetime,
 )
 from vessl.cli.organization import organization_name_option
 from vessl.dataset import (
@@ -89,8 +90,8 @@ def list():
     datasets = list_datasets()
     print_table(
         datasets,
-        ["ID", "Name", "Status", "Files", "Source"],
-        lambda x: [x.id, x.name, x.status, x.file_count, x.source.type],
+        ["Name", "Source", "Updated"],
+        lambda x: [x.name, x.source.type, truncate_datetime(x.updated_dt)],
     )
 
 
