@@ -41,10 +41,9 @@ def list(id: int, path: str, recursive: bool):
     prompter=generic_prompter("Volume ID", click.INT),
 )
 @click.option("-p", "--path", type=click.Path(), required=True)
-@click.option("-r", "--recursive", is_flag=True, help="Required if directory.")
-def delete(id: int, path: str, recursive: bool):
-    files = delete_volume_file(volume_id=id, path=path, recursive=recursive)
-    print(f"Deleted {id} ({len([x for x in files if not x.is_dir])} file(s)).")
+def delete(id: int, path: str):
+    delete_volume_file(volume_id=id, path=path)
+    print(f"Deleted {id}.")
 
 
 @cli.vessl_command()
@@ -72,16 +71,14 @@ def delete(id: int, path: str, recursive: bool):
     required=True,
     prompter=generic_prompter("Destination path"),
 )
-@click.option("-r", "--recursive", is_flag=True, help="Required if directory.")
 def copy(
-    source_id: int, source_path: str, dest_id: int, dest_path: str, recursive: bool
+    source_id: int, source_path: str, dest_id: int, dest_path: str,
 ):
     copy_volume_file(
         source_volume_id=source_id,
         source_path=source_path,
         dest_volume_id=dest_id,
         dest_path=dest_path,
-        recursive=recursive,
     )
 
 
@@ -110,8 +107,7 @@ def parse_volume_url(volume_url: str, raise_if_not_exists: bool = False):
     type=click.STRING,
     required=True,
 )
-@click.option("-r", "--recursive", is_flag=True)
-def cp(source: str, dest: str, recursive: bool):
+def cp(source: str, dest: str):
     """Volume copy method used in backend"""
 
     source_id, source_path = parse_volume_url(source, raise_if_not_exists=True)
@@ -122,5 +118,4 @@ def cp(source: str, dest: str, recursive: bool):
         source_path=source_path,
         dest_volume_id=dest_id,
         dest_path=dest_path,
-        recursive=recursive,
     )
