@@ -201,8 +201,7 @@ class UserMetricCollector(Collector):
 
         return distributed_info
 
-    def build_metric_payload(self, payload: Dict[str, Any]):
-        ts = time.time()
+    def build_metric_payload(self, payload: Dict[str, Any], ts: float):
         fields = payload
         tags = {"step": str(self.step)}
 
@@ -219,8 +218,7 @@ class UserMetricCollector(Collector):
             fields=fields,
         )
 
-    def build_image_payload(self, payload: Dict[str, Any]):
-        ts = time.time()
+    def build_media_payload(self, payload: Dict[str, Any], ts: float):
         fields = payload
         tags = {"step": str(self.step)}
 
@@ -241,7 +239,7 @@ class UserMetricCollector(Collector):
         self.add(payloads)
         return self.step
 
-    def log_images(self, payloads: List[ExperimentMetricEntry]) -> int:
+    def log_media(self, payloads: List[ExperimentMetricEntry]) -> int:
         self.add(payloads)
         return self.step
 
