@@ -20,13 +20,13 @@ from vessl.util.constant import (
     DATASET_VERSION_HASH_LATEST,
     EXPERIMENT_WORKING_DIR,
     MOUNT_PATH_EMPTY_DIR,
-    MOUNT_TYPE_ARCHIVE_FILE,
-    MOUNT_TYPE_CODE,
-    MOUNT_TYPE_DATASET,
-    MOUNT_TYPE_DATASET_VERSION,
-    MOUNT_TYPE_EMPTY_DIR,
-    MOUNT_TYPE_MODEL_VOLUME,
-    MOUNT_TYPE_OUTPUT,
+    SOURCE_TYPE_ARCHIVE_FILE,
+    SOURCE_TYPE_CODE,
+    SOURCE_TYPE_DATASET,
+    SOURCE_TYPE_DATASET_VERSION,
+    SOURCE_TYPE_EMPTY_DIR,
+    SOURCE_TYPE_MODEL_VOLUME,
+    SOURCE_TYPE_OUTPUT,
     TEMP_DIR,
 )
 from vessl.util.downloader import Downloader
@@ -83,12 +83,19 @@ def list_volume_files(
         )
         ```
     """
-    result = vessl_api.volume_file_list_api(
-        volume_id=volume_id,
-        recursive=recursive,
-        path=path,
-        need_download_url=need_download_url,
-    ).results
+    try:
+        result = vessl_api.volume_file_list_api(
+            volume_id=volume_id,
+            recursive=recursive,
+            path=path,
+            need_download_url=need_download_url,
+        ).results
+    except VesslApiException as e:
+        if path == "":
+            result = []
+        else:
+            raise e
+
     return sorted(result, key=lambda x: x.path)
 
 
@@ -338,23 +345,23 @@ def _print_volume_mount_requests_tree(
 ):
     print("Mount Info:")
     for request in requests.requests:
-        if request.mount_type == MOUNT_TYPE_ARCHIVE_FILE:
+        if request.source_type == SOURCE_TYPE_ARCHIVE_FILE:
             print(f"ㄴ {request.mount_path} -> (Uploaded)")
-        if request.mount_type == MOUNT_TYPE_CODE:
+        if request.source_type == SOURCE_TYPE_CODE:
             print(
                 f"ㄴ {request.mount_path} -> Code [{request.code.git_provider}@{request.code.git_owner}/{request.code.git_repo}@{request.code.git_ref}]"
             )
-        if request.mount_type == MOUNT_TYPE_DATASET:
+        if request.source_type == SOURCE_TYPE_DATASET:
             print(f"ㄴ {request.mount_path} -> Dataset [{request.dataset.dataset_name}]")
-        if request.mount_type == MOUNT_TYPE_DATASET_VERSION:
+        if request.source_type == SOURCE_TYPE_DATASET_VERSION:
             print(
                 f"ㄴ {request.mount_path} -> Dataset [{request.dataset_version.dataset_name}@{request.dataset_version.dataset_version_hash}]"
             )
-        if request.mount_type == MOUNT_TYPE_MODEL_VOLUME:
+        if request.source_type == SOURCE_TYPE_MODEL_VOLUME:
             print(
                 f"ㄴ {request.mount_path} -> Model [{request.model_volume.model_repository_name}/{request.model_volume.model_number}{request.model_volume.sub_path}]"
             )
-        if request.mount_type == MOUNT_TYPE_OUTPUT:
+        if request.source_type == SOURCE_TYPE_OUTPUT:
             print(f"ㄴ {request.mount_path} -> (output)")
 
 
@@ -435,7 +442,7 @@ def _configure_volume_mount_request_datasets(
             dataset = project_dataset.dataset
 
             dataset_mount_map[dataset.id] = ProtoVolumeMountRequest(
-                mount_type=MOUNT_TYPE_DATASET,
+                source_type=SOURCE_TYPE_DATASET,
                 mount_path=mount_path,
                 dataset=ProtoVolumeMountRequestSourceDataset(
                     dataset_id=dataset.id,
@@ -463,7 +470,7 @@ def _configure_volume_mount_request_datasets(
 
         if not dataset.is_version_enabled:
             dataset_mount_map[dataset.id] = ProtoVolumeMountRequest(
-                mount_type=MOUNT_TYPE_DATASET,
+                source_type=SOURCE_TYPE_DATASET,
                 mount_path=mount_path,
                 dataset=ProtoVolumeMountRequestSourceDataset(
                     dataset_id=dataset.id,
@@ -477,7 +484,7 @@ def _configure_volume_mount_request_datasets(
             ).version_hash  # Get full version hash from truncated one given by input
 
             dataset_mount_map[dataset.id] = ProtoVolumeMountRequest(
-                mount_type=MOUNT_TYPE_DATASET_VERSION,
+                source_type=SOURCE_TYPE_DATASET_VERSION,
                 mount_path=mount_path,
                 dataset_version=ProtoVolumeMountRequestSourceDatasetVersion(
                     dataset_id=dataset.id,
@@ -504,7 +511,7 @@ def _configure_volume_mount_request_model(
     )
 
     return ProtoVolumeMountRequest(
-        mount_type=MOUNT_TYPE_MODEL_VOLUME,
+        source_type=SOURCE_TYPE_MODEL_VOLUME,
         mount_path=mount_path,
         model_volume=ProtoVolumeMountRequestSourceModelVolume(
             sub_path="/",
@@ -626,7 +633,7 @@ def _configure_volume_mount_request_code(
             vmr_source_code.git_diff_file = diff_mount_file
 
     return ProtoVolumeMountRequest(
-        mount_type=MOUNT_TYPE_CODE,
+        source_type=SOURCE_TYPE_CODE,
         mount_path=ref_mount_path,
         code=vmr_source_code,
     )
@@ -638,7 +645,7 @@ def _configure_volume_mount_request_archive_file(
     mount_path, archive_file_path = archive_file_mount.split(":", 1)
 
     return ProtoVolumeMountRequest(
-        mount_type=MOUNT_TYPE_ARCHIVE_FILE,
+        source_type=SOURCE_TYPE_ARCHIVE_FILE,
         mount_path=mount_path,
         archive_file=ProtoVolumeMountRequestSourceArchiveFile(
             archive_file=archive_file_path,
@@ -648,13 +655,13 @@ def _configure_volume_mount_request_archive_file(
 
 def _configure_volume_mount_request_empty_dir() -> ProtoVolumeMountRequest:
     return ProtoVolumeMountRequest(
-        mount_type=MOUNT_TYPE_EMPTY_DIR,
+        source_type=SOURCE_TYPE_EMPTY_DIR,
         mount_path=MOUNT_PATH_EMPTY_DIR,
     )
 
 
 def _configure_volume_mount_request_output(output_dir: str) -> ProtoVolumeMountRequest:
     return ProtoVolumeMountRequest(
-        mount_type=MOUNT_TYPE_OUTPUT,
+        source_type=SOURCE_TYPE_OUTPUT,
         mount_path=output_dir,
     )
